==> ij-segment-wrapper-2.1.0.tgz: package/lib/gtmMiddleware.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
var TCF_COOKIE_KEY = 'borosTcf';

var readCookie = function readCookie(key, cookies) {
  var re = new RegExp(key + '=([^;]+)');
  var value = re.exec(cookies);
  return value !== null ? value[1] : null;
};

export var isUserFirstVisit = function isUserFirstVisit(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      cookies = _ref.cookies;

  var cookieValue = readCookie(TCF_COOKIE_KEY, cookies);
  return cookieValue === null;
};

var integrationsAreDeactivated = function integrationsAreDeactivated(integrations) {
  return integrations.All === false;
};

var defaultIsFirstVisit = isUserFirstVisit({
  cookies: document.cookie
});
/**
 * We only want to track in GTM those events who have
 * been tracked by the backend already
 */

export var gtmMiddleware = function gtmMiddleware(_ref2) {
  var payload = _ref2.payload,
      next = _ref2.next,
      _ref2$whitelist = _ref2.whitelist,
      whitelist = _ref2$whitelist === void 0 ? [] : _ref2$whitelist,
      _ref2$isFirstVisit = _ref2.isFirstVisit,
      isFirstVisit = _ref2$isFirstVisit === void 0 ? defaultIsFirstVisit : _ref2$isFirstVisit;
  var _payload$obj = payload.obj,
      integrations = _payload$obj.integrations,
      event = _payload$obj.event;
  var isPageView = event.endsWith('Viewed');
  var isWhitelistEvent = whitelist.includes(event);

  if (integrationsAreDeactivated(integrations) || !isPageView || isWhitelistEvent) {
    return next(payload);
  }

  if (isFirstVisit) {
    return next(payload);
  } // activates GTM only


  payload.obj.integrations = {
    All: false,
    'Google Tag Manager': true
  };
  next(payload);
};
/**
 * Middleware factory to pass a whitelist to the gtmMiddleware function
 */

export var makeGtmMiddleware = function makeGtmMiddleware(_temp2) {
  var _ref3 = _temp2 === void 0 ? {} : _temp2,
      _ref3$whitelist = _ref3.whitelist,
      whitelist = _ref3$whitelist === void 0 ? [] : _ref3$whitelist;

  return function (params) {
    gtmMiddleware(_extends({}, params, {
      whitelist: whitelist
    }));
  };
};

==> ij-segment-wrapper-2.2.0.tgz: package/lib/gtmMiddleware.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
var TCF_COOKIE_KEY = 'borosTcf';

var readCookie = function readCookie(key, cookies) {
  var re = new RegExp(key + '=([^;]+)');
  var value = re.exec(cookies);
  return value !== null ? value[1] : null;
};

export var isUserFirstVisit = function isUserFirstVisit(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      cookies = _ref.cookies;

  var cookieValue = readCookie(TCF_COOKIE_KEY, cookies);
  return cookieValue === null;
};

var integrationsAreDeactivated = function integrationsAreDeactivated(integrations) {
  return integrations.All === false;
};

var defaultIsFirstVisit = isUserFirstVisit({
  cookies: document.cookie
});
/**
 * We only want to track in GTM those events who have
 * been tracked by the backend already
 */

export var gtmMiddleware = function gtmMiddleware(_ref2) {
  var payload = _ref2.payload,
      next = _ref2.next,
      _ref2$whitelist = _ref2.whitelist,
      whitelist = _ref2$whitelist === void 0 ? [] : _ref2$whitelist,
      _ref2$isFirstVisit = _ref2.isFirstVisit,
      isFirstVisit = _ref2$isFirstVisit === void 0 ? defaultIsFirstVisit : _ref2$isFirstVisit;
  var _payload$obj = payload.obj,
      integrations = _payload$obj.integrations,
      event = _payload$obj.event;
  var isPageView = event.endsWith('Viewed');
  var isWhitelistEvent = whitelist.includes(event);

  if (integrationsAreDeactivated(integrations) && isPageView && !isFirstVisit && !isWhitelistEvent) {
    payload.obj.integrations = {
      All: false
    };
    return next(payload);
  }

  if (integrationsAreDeactivated(integrations) || !isPageView || isWhitelistEvent || isFirstVisit) {
    return next(payload);
  } // activates GTM only


  payload.obj.integrations = {
    All: false,
    'Google Tag Manager': true
  };
  next(payload);
};
/**
 * Middleware factory to pass a whitelist to the gtmMiddleware function
 */

export var makeGtmMiddleware = function makeGtmMiddleware(_temp2) {
  var _ref3 = _temp2 === void 0 ? {} : _temp2,
      _ref3$whitelist = _ref3.whitelist,
      whitelist = _ref3$whitelist === void 0 ? [] : _ref3$whitelist;

  return function (params) {
    gtmMiddleware(_extends({}, params, {
      whitelist: whitelist
    }));
  };
};
